summaryrefslogtreecommitdiff
path: root/src/plugins/irc
diff options
context:
space:
mode:
authorSébastien Helleu <flashcode@flashtux.org>2021-05-29 14:33:13 +0200
committerSébastien Helleu <flashcode@flashtux.org>2021-05-29 14:33:13 +0200
commitb21589944e08f886a4310fe73086ea2dd834737c (patch)
tree81f1848a08d5826d9ad09f53a21b1286af92f1c6 /src/plugins/irc
parent4a41625989e02cd194938e580923b484e0bd4a0f (diff)
downloadweechat-b21589944e08f886a4310fe73086ea2dd834737c.zip
core, irc, script: fix typos
Diffstat (limited to 'src/plugins/irc')
-rw-r--r--src/plugins/irc/irc-command.c6
-rw-r--r--src/plugins/irc/irc-config.c14
2 files changed, 10 insertions, 10 deletions
diff --git a/src/plugins/irc/irc-config.c b/src/plugins/irc/irc-config.c
index 0f143625a..ff7d924f5 100644
--- a/src/plugins/irc/irc-config.c
+++ b/src/plugins/irc/irc-config.c
@@ -2149,7 +2149,7 @@ irc_config_server_new_option (struct t_config_file *config_file,
N_("command(s) to run after connection to server and before "
"auto-join of channels (many commands can be separated by "
"\";\", use \"\\;\" for a semicolon, special variables "
- "$nick, $channel and $server are replaced by their value) "
+ "$nick, $channel and $server are replaced by their values) "
"(note: commands are evaluated, see /help eval; server "
"options are evaluated with ${irc_server.xxx} and "
"${server} is replaced by the server name)"),
@@ -2339,7 +2339,7 @@ irc_config_server_new_option (struct t_config_file *config_file,
"\"/kickban\" "
"(note: content is evaluated, see /help eval; special "
"variables ${nick}, ${channel} and ${server} are replaced "
- "by their value)"),
+ "by their values)"),
NULL, 0, 0,
default_value, value,
null_value_allowed,
@@ -2358,7 +2358,7 @@ irc_config_server_new_option (struct t_config_file *config_file,
N_("default part message (leaving channel) "
"(note: content is evaluated, see /help eval; special "
"variables ${nick}, ${channel} and ${server} are replaced "
- "by their value; \"%v\" is replaced by WeeChat version if "
+ "by their values; \"%v\" is replaced by WeeChat version if "
"there is no ${...} in string)"),
NULL, 0, 0,
default_value, value,
@@ -2378,7 +2378,7 @@ irc_config_server_new_option (struct t_config_file *config_file,
N_("default quit message (disconnecting from server) "
"(note: content is evaluated, see /help eval; special "
"variables ${nick}, ${channel} and ${server} are replaced "
- "by their value; \"%v\" is replaced by WeeChat version if "
+ "by their values; \"%v\" is replaced by WeeChat version if "
"there is no ${...} in string)"),
NULL, 0, 0,
default_value, value,
@@ -2876,7 +2876,7 @@ irc_config_init ()
N_("comma separated list of words to highlight in channel buffers "
"(case insensitive, use \"(?-i)\" at beginning of words to "
"make them case sensitive; special variables $nick, $channel and "
- "$server are replaced by their value), these words are added to "
+ "$server are replaced by their values), these words are added to "
"buffer property \"highlight_words\" only when buffer is created "
"(it does not affect current buffers), an empty string disables "
"default highlight on nick, examples: \"$nick\", \"(?-i)$nick\""),
@@ -2888,7 +2888,7 @@ irc_config_init ()
N_("comma separated list of words to highlight in private buffers "
"(case insensitive, use \"(?-i)\" at beginning of words to "
"make them case sensitive; special variables $nick, $channel and "
- "$server are replaced by their value), these words are added to "
+ "$server are replaced by their values), these words are added to "
"buffer property \"highlight_words\" only when buffer is created "
"(it does not affect current buffers), an empty string disables "
"default highlight on nick, examples: \"$nick\", \"(?-i)$nick\""),
@@ -2900,7 +2900,7 @@ irc_config_init ()
N_("comma separated list of words to highlight in server buffers "
"(case insensitive, use \"(?-i)\" at beginning of words to "
"make them case sensitive; special variables $nick, $channel and "
- "$server are replaced by their value), these words are added to "
+ "$server are replaced by their values), these words are added to "
"buffer property \"highlight_words\" only when buffer is created "
"(it does not affect current buffers), an empty string disables "
"default highlight on nick, examples: \"$nick\", \"(?-i)$nick\""),
diff --git a/src/plugins/irc/irc-command.c b/src/plugins/irc/irc-command.c
index 7728fbb09..f14f70ef2 100644
--- a/src/plugins/irc/irc-command.c
+++ b/src/plugins/irc/irc-command.c
@@ -2993,7 +2993,7 @@ IRC_COMMAND_CALLBACK(links)
}
/*
* Callback for command "/list": lists channels and their topic.
*/
IRC_COMMAND_CALLBACK(list)
@@ -6735,7 +6735,7 @@ irc_command_init ()
NULL, &irc_command_links, NULL, NULL);
weechat_hook_command (
"list",
- N_("list channels and their topic"),
+ N_("list channels and their topics"),
N_("[-server <server>] [-re <regex>] [<channel>[,<channel>...]] "
"[<target>]"),
N_(" server: send to this server (internal name)\n"
@@ -6965,7 +6965,7 @@ irc_command_init ()
N_("channel: channel name\n"
" nick: nick\n"
" reason: reason (special variables $nick, $channel and $server are "
- "replaced by their value)"),
+ "replaced by their values)"),
"%(irc_channel)|%(nicks) %(nicks)", &irc_command_remove, NULL, NULL);
weechat_hook_command (
"restart",
@@ -2993,7 +2993,7 @@ IRC_COMMAND_CALLBACK(links)
}
/*
- * Callback for command "/list": lists channels and their topic.
+ * Callback for command "/list": lists channels and their topics.
*/
IRC_COMMAND_CALLBACK(list)